==> infinispan-server-8.0.0.Beta2-sources.zip: infinispan-server-sources-8.0.0.Beta2/infinispan/src/main/java/org/jboss/as/clustering/infinispan/subsystem/InvalidationCacheResource.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2012, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.clustering.infinispan.subsystem;

import org.jboss.as.controller.PathElement;
import org.jboss.as.controller.services.path.ResolvePathHandler;

/**
 * Resource description for the addressable resource /subsystem=infinispan/cache-container=X/invalidation-cache=*
 *
 * @author Richard Achmatowicz (c) 2011 Red Hat Inc.
 */
public class InvalidationCacheResource extends ClusteredCacheResource {

    public static final PathElement INVALIDATION_CACHE_PATH = PathElement.pathElement(ModelKeys.INVALIDATION_CACHE);

    // attributes

    public InvalidationCacheResource(final ResolvePathHandler resolvePathHandler, boolean runtimeRegistration) {
        super(INVALIDATION_CACHE_PATH,
                new InfinispanResourceDescriptionResolver(ModelKeys.INVALIDATION_CACHE),
                InvalidationCacheAdd.INSTANCE,
                new CacheRemoveHandler(), resolvePathHandler, runtimeRegistration);
    }
}

==> infinispan-server-8.2.0.Beta2-sources.zip: infinispan-server-sources-8.2.0.Beta2/infinispan/src/main/java/org/jboss/as/clustering/infinispan/subsystem/InvalidationCacheResource.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2012, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.clustering.infinispan.subsystem;

import org.jboss.as.controller.PathElement;
import org.jboss.as.controller.services.path.ResolvePathHandler;

/**
 * Resource description for the addressable resource /subsystem=infinispan/cache-container=X/invalidation-cache=*
 *
 * @author Richard Achmatowicz (c) 2011 Red Hat Inc.
 */
public class InvalidationCacheResource extends ClusteredCacheResource {

    public static final PathElement PATH = PathElement.pathElement(ModelKeys.INVALIDATION_CACHE);

    // attributes

    public InvalidationCacheResource(final ResolvePathHandler resolvePathHandler, boolean runtimeRegistration) {
        super(PATH,
                new InfinispanResourceDescriptionResolver(ModelKeys.INVALIDATION_CACHE),
                InvalidationCacheAdd.INSTANCE,
                new CacheRemoveHandler(), resolvePathHandler, runtimeRegistration);
    }
}
